import { NextFunction, Request, Response } from "express";
import { StatusCodes } from "http-status-codes";

const validateBearerToken = (authorizationHeader: string | undefined): boolean => {
    if (!authorizationHeader) {
        console.log("Authorization header is missing!");
        return false;
    }

    const token = authorizationHeader.split(' ')[1]; // Extract token after 'Bearer'
    if (!token) {
        console.log("Bearer token is missing!");
        return false;
    }

    if (token !== process.env.WEBHOOK_TOKEN) {
        console.log("Bearer token is incorrect!");
        return false;
    }

    return true;
};

export function authenticateHeader(req: Request, res: Response, next: NextFunction) {
    try {
        const authorizationHeader = req.headers['authorization'];

        if (!validateBearerToken(authorizationHeader as string)) {
            res.status(StatusCodes.UNAUTHORIZED).json({ error: "Authentication failed" });
            return;
        }
        //console.log("Bearer token is correct!");
        next();
    } catch (error) {
        res.status(StatusCodes.INTERNAL_SERVER_ERROR)
            .json({ error: "Internal Server Error" });
    }
};



