import {injectable } from "tsyringe";
import { Counter, Gauge, collectDefaultMetrics} from "prom-client";

// Collect default system metrics (e.g., CPU, memory usage)
const prefix = 'locationhub_';
collectDefaultMetrics({ prefix });

@injectable()
export class MetricsService {
  constructor(
  ) { }

  public getRequestCounter() {
    const requestCounter = new Counter({
      name: `${prefix}http_requests_total`,
      help: "Total number of HTTP requests",
      labelNames: ["method", "route", "status"],
    });
    return requestCounter;
  }

  public getLocationsTotal() {
    const locationsTotal = new Gauge({
      name: `${prefix}locations_total`,
      help: "Total number of location entries in database",
      labelNames: ["database"],
    });
    return locationsTotal;
  }
  public getGnssLocationsTotal() {
    const gnssLocationsTotal = new Gauge({
      name: `${prefix}gnss_locations_total`,
      help: "Total number of location entries with GNSS in database",
      labelNames: ["database"],
    });
    return gnssLocationsTotal;
  }
  public getWifiLocationTotal() {
    const wifiLocationTotal = new Gauge({
      name: `${prefix}wifi_locations_total`,
      help: "Total number of wifi location entries in database",
      labelNames: ["database"],
    });
    return wifiLocationTotal;
  }
  public getWifiLocationResolvable() {
    const wifiLocationNotResolvable = new Gauge({
      name: `${prefix}wifi_locations_not_resolvable`,
      help: "Unresolved number of wifi location entries in database",
      labelNames: ["database"],
    });
    return wifiLocationNotResolvable;
  }
  public getLWifiLocationRequestLimitExceeded() {
    const wifiLocationRequestLimitExceeded = new Gauge({
      name: `${prefix}wifi_locations_request_limit_exceeded`,
      help: "Unresolved number of wifi location because request limit exceeded entries in database",
      labelNames: ["database"],
    });
    return wifiLocationRequestLimitExceeded;
  }
  public getTnnGatewayReceptions() {
    const ttnGatewayReceptions = new Gauge({
      name: `${prefix}ttn_gateway_receptions`,
      help: "Total number of TTN Gateway receptions entries in database",
      labelNames: ["database"],
    });
    return ttnGatewayReceptions;
  }
}
